Index: wp-includes/script-loader.php
===================================================================
--- wp-includes/script-loader.php	(revision 19998)
+++ wp-includes/script-loader.php	(working copy)
@@ -359,7 +359,7 @@
 
 		$scripts->add( 'admin-widgets', "/wp-admin/js/widgets$suffix.js", array( 'jquery-ui-sortable', 'jquery-ui-draggable', 'jquery-ui-droppable' ), false, 1 );
 
-		$scripts->add( 'theme', "/wp-admin/js/theme$suffix.js", array( 'thickbox' ), false, 1 );
+		$scripts->add( 'theme', "/wp-admin/js/theme$suffix.js", array( 'jquery' ), false, 1 );
 
 		$scripts->add( 'theme-preview', "/wp-admin/js/theme-preview$suffix.js", array( 'thickbox', 'jquery' ), false, 1 );
 
Index: wp-admin/includes/class-wp-themes-list-table.php
===================================================================
--- wp-admin/includes/class-wp-themes-list-table.php	(revision 19998)
+++ wp-admin/includes/class-wp-themes-list-table.php	(working copy)
@@ -11,7 +11,7 @@
 
 	var $search = array();
 	var $features = array();
-	
+
 	function __construct() {
 		parent::__construct( array(
 			'ajax' => true,
@@ -145,22 +145,20 @@
 	$parent_theme = $themes[$theme_name]['Parent Theme'];
 	$theme_root = $themes[$theme_name]['Theme Root'];
 	$theme_root_uri = $themes[$theme_name]['Theme Root URI'];
-	$preview_link = esc_url( add_query_arg( array( 'preview' => 1, 'template' => $template, 'stylesheet' => $stylesheet, 'preview_iframe' => true, 'TB_iframe' => 'true' ), home_url( '/' ) ) );
-	$preview_text = esc_attr( sprintf( __( 'Preview of &#8220;%s&#8221;' ), $title ) );
 	$tags = $themes[$theme_name]['Tags'];
-	$thickbox_class = 'thickbox thickbox-preview';
+	$customize_data = sprintf( 'data-stylesheet="%s" data-template="%s"', esc_attr( $stylesheet ), esc_attr( $template ) );
 	$activate_link = wp_nonce_url( "themes.php?action=activate&amp;template=" . urlencode( $template ) . "&amp;stylesheet=" . urlencode( $stylesheet ), 'switch-theme_' . $template );
 	$activate_text = esc_attr( sprintf( __( 'Activate &#8220;%s&#8221;' ), $title ) );
 	$actions = array();
 	$actions[] = '<a href="' . $activate_link . '" class="activatelink" title="' . $activate_text . '">' . __( 'Activate' ) . '</a>';
-	$actions[] = '<a href="' . $preview_link . '" class="thickbox thickbox-preview" title="' . esc_attr( sprintf( __( 'Preview &#8220;%s&#8221;' ), $theme_name ) ) . '">' . __( 'Preview' ) . '</a>';
+	$actions[] = '<a class="activate-customizer hide-if-no-js" href="#" title="' . esc_attr( sprintf( __( 'Customize &#8220;%s&#8221;' ), $theme_name ) ) . '"' . $customize_data . '>' . __( 'Customize' ) . '</a>';
 	if ( ! is_multisite() && current_user_can( 'delete_themes' ) )
 		$actions[] = '<a class="submitdelete deletion" href="' . wp_nonce_url( "themes.php?action=delete&amp;template=$stylesheet", 'delete-theme_' . $stylesheet ) . '" onclick="' . "return confirm( '" . esc_js( sprintf( __( "You are about to delete this theme '%s'\n  'Cancel' to stop, 'OK' to delete." ), $theme_name ) ) . "' );" . '">' . __( 'Delete' ) . '</a>';
 	$actions = apply_filters( 'theme_action_links', $actions, $themes[$theme_name] );
 
 	$actions = implode ( ' | ', $actions );
 ?>
-		<a href="<?php echo $preview_link; ?>" class="<?php echo $thickbox_class; ?> screenshot">
+		<a href="#" class="screenshot activate-customizer" <?php echo $customize_data; ?>>
 <?php if ( $screenshot ) : ?>
 			<img src="<?php echo $theme_root_uri . '/' . $stylesheet . '/' . $screenshot; ?>" alt="" />
 <?php endif; ?>
Index: wp-admin/themes.php
===================================================================
--- wp-admin/themes.php	(revision 19998)
+++ wp-admin/themes.php	(working copy)
@@ -66,8 +66,6 @@
 	'<p>' . __('<a href="http://wordpress.org/support/" target="_blank">Support Forums</a>') . '</p>'
 );
 
-add_thickbox();
-wp_enqueue_script( 'theme-preview' );
 wp_enqueue_script( 'theme' );
 
 endif;

Index: wp-includes/js/customize-loader.dev.js
===================================================================
--- wp-includes/js/customize-loader.dev.js	(revision 19998)
+++ wp-includes/js/customize-loader.dev.js	(working copy)
@@ -48,26 +48,19 @@
 		Loader.initialize();
 
 		// Override 'preview' links on themes page.
-		$('.thickbox-preview').click( function( event ) {
-			var href, template, stylesheet;
-
-			// Stop the thickbox.
+		$('.activate-customizer').click( function( event ) {
 			event.preventDefault();
-			event.stopImmediatePropagation();
 
-			// Extract the template/stylesheet from the preview link's url.
-			href = $(this).attr('href');
-			template = href.match('template=([^&]*)')[1];
-			stylesheet = href.match('stylesheet=([^&]*)')[1];
+			// Extract the template/stylesheet from the data attributes.
+			template = $(this).data( 'template' );
+			stylesheet = $(this).data( 'stylesheet' );
 
 			// Load the theme.
 			Loader.open({
 				template: template,
 				stylesheet: stylesheet
 			});
-		}).filter( function() {
-			return 'Preview' == $(this).text();
-		}).text('Customize');
+		})
 	});
 
 	// Expose the API to the world.